@@ -6,16 +6,21 @@ from __future__ import annotations
 from enum import Enum
 from typing import Dict, List, Optional
 
-from pydantic import validator, BaseModel, Field
+from pydantic import validator, BaseModel, Field, HttpUrl
 
 from fideslang.validation import (
     FidesKey,
     sort_list_objects_by_name,
     no_self_reference,
     matching_parent_key,
+    check_valid_country_code,
 )
 
 # Reusable components
+country_code_validator = validator("third_country_transfers", allow_reuse=True)(
+    check_valid_country_code
+)
+
 matching_parent_key_validator = validator("parent_key", allow_reuse=True, always=True)(
     matching_parent_key
 )
@@ -48,6 +53,21 @@ class FidesModel(BaseModel):
         orm_mode = True
 
 
+class LegalBasisEnum(str, Enum):
+    """
+    The model for allowable legal basis categories
+
+    Based upon article 6 of the GDPR
+    """
+
+    CONSENT = "Consent"
+    CONTRACT = "Contract"
+    LEGAL_OBLIGATION = "Legal Obligation"
+    VITAL_INTEREST = "Vital Interest"
+    PUBLIC_INTEREST = "Public Interest"
+    LEGITIMATE_INTEREST = "Legitimate Interests"
+
+
 # Privacy Data Types
 class DataCategory(FidesModel):
     """The DataCategory resource model."""
@@ -75,6 +95,8 @@ class DataUse(FidesModel):
     """The DataUse resource model."""
 
     parent_key: Optional[FidesKey]
+    legal_basis: Optional[LegalBasisEnum]
+    recipients: Optional[List[str]]
 
     _matching_parent_key: classmethod = matching_parent_key_validator
     _no_self_reference: classmethod = no_self_reference_validator
@@ -94,6 +116,7 @@ class DatasetField(BaseModel):
     data_qualifier: FidesKey = Field(
         default="aggregated.anonymized.unlinked_pseudonymized.pseudonymized.identified",
     )
+    retention: Optional[str]
     fields: Optional[List[DatasetField]]
 
 
@@ -110,6 +133,7 @@ class DatasetCollection(BaseModel):
     data_qualifier: FidesKey = Field(
         default="aggregated.anonymized.unlinked_pseudonymized.pseudonymized.identified",
     )
+    retention: Optional[str]
     fields: List[DatasetField]
 
     _sort_fields: classmethod = validator("fields", allow_reuse=True)(
@@ -142,11 +166,14 @@ class Dataset(FidesModel):
     data_qualifier: FidesKey = Field(
         default="aggregated.anonymized.unlinked_pseudonymized.pseudonymized.identified",
     )
+    joint_controller: Optional[ContactDetails]
+    retention: Optional[str] = "No retention or erasure policy"
+    third_country_transfers: Optional[List[str]]
     collections: List[DatasetCollection]
     _sort_collections: classmethod = validator("collections", allow_reuse=True)(
         sort_list_objects_by_name
     )
-    joint_controller: Optional[ContactDetails]
+    _check_valid_country_code: classmethod = country_code_validator
 
 
 # Evaluation
@@ -192,6 +219,25 @@ class Evaluation(BaseModel):
 
 
 # Organization
+class ResourceFilter(BaseModel):
+    """
+    The ResourceFilter resource model.
+    """
+
+    type: str
+    value: str
+
+
+class OrganizationMetadata(BaseModel):
+    """
+    The OrganizationMetadata resource model.
+
+    Object used to hold application specific metadata for an organization
+    """
+
+    resource_filters: Optional[List[ResourceFilter]]
+
+
 class Organization(FidesModel):
     """
     The Organization resource model.
@@ -203,13 +249,15 @@ class Organization(FidesModel):
     organization_parent_key: None = None
     controller: Optional[ContactDetails]
     data_protection_officer: Optional[ContactDetails]
+    fidesctl_meta: Optional[OrganizationMetadata]
     representative: Optional[ContactDetails]
+    security_policy: Optional[HttpUrl]
 
 
 # Policy
 class MatchesEnum(str, Enum):
     """
-    The MatchesEnum resouce model.
+    The MatchesEnum resource model.
 
     Determines how the listed resources are matched in the evaluation logic.
     """
@@ -290,6 +338,18 @@ class PrivacyDeclaration(BaseModel):
     dataset_references: Optional[List[FidesKey]]
 
 
+class SystemMetadata(BaseModel):
+    """
+    The SystemMetadata resource model.
+
+    Object used to hold application specific metadata for a system
+    """
+
+    resource_id: Optional[str]
+    endpoint_address: Optional[str]
+    endpoint_port: Optional[str]
+
+
 class System(FidesModel):
     """
     The System resource model.
@@ -299,10 +359,13 @@ class System(FidesModel):
 
     registry_id: Optional[int]
     meta: Optional[Dict[str, str]]
+    fidesctl_meta: Optional[SystemMetadata]
     system_type: str
     privacy_declarations: List[PrivacyDeclaration]
     system_dependencies: Optional[List[FidesKey]]
     joint_controller: Optional[ContactDetails]
+    third_country_transfers: Optional[List[str]]
+    administrating_department: Optional[str] = "Not defined"
 
     _sort_privacy_declarations: classmethod = validator(
         "privacy_declarations", allow_reuse=True
@@ -312,6 +375,8 @@ class System(FidesModel):
         "system_dependencies", allow_reuse=True, each_item=True
     )(no_self_reference)
 
+    _check_valid_country_code: classmethod = country_code_validator
+
 
 # Taxonomy
 class Taxonomy(BaseModel):
